@@ -1,6 +1,11 @@
 /*
  * This file is part of John the Ripper password cracker,
- * Copyright (c) 1996-98 by Solar Designer
+ * Copyright (c) 1996-98,2013 by Solar Designer
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted.
+ *
+ * There's ABSOLUTELY NO WARRANTY, express or implied.
  */
 
 /*
@@ -39,20 +44,27 @@ extern void list_init(struct list_main **list);
  */
 extern void list_add(struct list_main *list, char *data);
 
+/*
+ * Adds a previously allocated entry to the list.
+ */
+extern void list_add_link(struct list_main *list, struct list_entry *entry);
+
 /*
  * Adds multiple entries to the list from a comma-separated string.
  */
 extern void list_add_multi(struct list_main *list, char *data);
 
 /*
- * Adds an entry to the list checking for dupes. This is slow, and should
+ * Adds an entry to the list checking for dupes.  This is slow, and should
  * only be used on tiny lists.
  */
 extern void list_add_unique(struct list_main *list, char *data);
 
+#if 0
 /*
  * Deletes the entry following prev from the list.
  */
 extern void list_del_next(struct list_main *list, struct list_entry *prev);
+#endif
 
 #endif
